clear
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Run model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% IRBC model
dynare incompletemarkets
save simulation0 dr_ ys_ lgy_ lgx_

% open economy model with sticky intermediate prices
% and wages
dynare stickyopen
save simulation1 dr_ ys_ lgy_ lgx_

% open economy model with sticky intermediate prices,
% wages, and export prices
dynare stickyopenlcp
save simulation2 dr_ ys_ lgy_ lgx_

% number of periods for IRFs.
nperiods = 20;

%%%% Make figure to compare simulations
load simulation0 

shock = [0    %merr
         0    %merr2
         0.01 %nerr
         0];  %nerr2
dset = 'f0';        
makeirf

load simulation1
shock = [0
         0
         0.01
         0];
dset = 'f1';        
makeirf

load simulation2
shock = [0
         0
         0.01
         0];
dset = 'f2';        
makeirf



titlelist = char('Output','Capital (next period)','Investment','Consumption','Ex-ante Real Interest Rate','Labor');
legendlist = char('Flex','Sticky');
figlabel = 'Responses to a 1% increase in productivity';
makechart(titlelist,legendlist,figlabel,...
          100*[f0_gdp_irf/f0_gdp, f0_kp_irf/f0_kp, f0_ip_irf/f0_ip, f0_cc_irf/f0_cc, f0_rs_irf, f0_le_irf/f0_le],...
          100*[f1_gdp_irf/f1_gdp, f1_kp_irf/f1_kp, f1_ip_irf/f1_ip, f1_cc_irf/f1_cc, f1_rrs_irf, f1_le_irf/f1_le])


titlelist = char('Imports','Exports','RER Production Based','Trade Balance (share of GDP)','RER Consumption Based','Net Foreign Assets (share of gdp)');
legendlist = char('Flex','Sticky');
figlabel = 'Responses to a 1% increase in productivity';
makechart(titlelist,legendlist,figlabel,...
          100*[f0_ccm_irf/f0_ccm, f0_ccm2_irf/f0_ccm2, f0_pf_irf/f0_pf, f0_tby_irf, f0_q_irf/f0_q, f0_nfay_irf],...
          100*[f1_ccm_irf/f1_ccm, f1_ccm2_irf/f1_ccm2, f1_pm_irf/f1_pm, f1_tby_irf, f1_rerpc_irf/f1_rerpc, f1_nfay_irf])
   

titlelist = char('Output','Capital (next period)','Investment','Consumption','Ex-ante Real Interest Rate','Labor');
legendlist = char('PCP','LCP');
figlabel = 'Responses to a 1% increase in productivity';
makechart(titlelist,legendlist,figlabel,...
          100*[f1_gdp_irf/f1_gdp, f1_kp_irf/f1_kp, f1_ip_irf/f1_ip, f1_cc_irf/f1_cc, f1_rs_irf, f1_le_irf/f1_le],...
          100*[f2_gdp_irf/f2_gdp, f2_kp_irf/f2_kp, f2_ip_irf/f2_ip, f2_cc_irf/f2_cc, f2_rs_irf, f2_le_irf/f2_le])
      
      
titlelist = char('Imports','Exports','Real Exchange Rate (production-based)','Trade Balance (share of GDP)','Relative Price of Imports','Net Foreign Assets (share of gdp)');
legendlist = char('PCP','LCP');
figlabel = 'Responses to a 1% increase in productivity';
makechart(titlelist,legendlist,figlabel,...
          100*[f1_ccm_irf/f1_ccm, f1_ccm2_irf/f1_ccm2, f1_rer_irf/f1_rer, f1_tby_irf, f1_pm_irf/f1_pm, f1_nfay_irf],...
          100*[f2_ccm_irf/f2_ccm, f2_ccm2_irf/f2_ccm2, f2_rer_irf/f2_rer, f2_tby_irf, f2_pm_irf/f2_pm, f2_nfay_irf])
