// IRBC model 
// with variable labor

var cc, le, lambda, gamma, gdp, ip ,kp, rw, rk, n, m, rs, ccd, ccm, pf, pc, nfa, nfay, tby, q, sy, ipy
    cc2, le2, lambda2, gamma2, gdp2, ip2 ,kp2, rw2, rk2, n2, m2, ccd2, ccm2, pf2, pc2, rs2, tby2, q2;

varexo nerr, merr, nerr2, merr2;

// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// % define parameters here
// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

parameters beta_p, chi_p, le_p, delta_p, el, theta_p, 
           kpshr_p, nu_p, s_p, chi0_p, rhon_p, rhom_p, omega, rhoc, nfa_p;


// Discount factor  (default .99)
beta_p = 0.99;

// Frisch Elasticity of labor supply (2/chi_p);
chi_p = 10;

// Steady state labor supply
le_p = 0.5;

// depreciation rate (default 0.025)
delta_p = 0.025;

// elasticity of substitution between capital and labor
 
// Capital share
kpshr_p = 0.3;

// Set nu so as to hit desired capital share
nu_p = kpshr_p;

// saving rate
s_p = (nu_p/(delta_p-1+1/beta_p))*(delta_p);  

// parameter determining labor supply in SS
chi0_p = (1-le_p)^(chi_p)*(1/(1-s_p))*(1/le_p)*(1-nu_p);

omega = 0.8;


el = 2
rhoc = 1/(el-1);



rhon_p = 0.95;    
rhom_p = 0.95;
     
nfa_p = 0.001;
  
model;
///////////////////////////////////////////////////////////////////////////
// Country 1
///////////////////////////////////////////////////////////////////////////

// FOC with respect to consumption
1/cc - lambda*pc=0;   

// FOC wrt Labor
-chi0_p*(1-le)^(-chi_p) + lambda * rw =0;

// Lambda Marginal Utility of consumption
gamma-lambda = 0;

// gamma shadow price of capital
(1-delta_p)*beta_p * gamma(1) - gamma +beta_p *lambda(1)*rk(1) = 0;

// Aggregate Output
gdp = (kp(-1)*exp(m))^(nu_p)*(le*exp(n))^(1-nu_p);

// resource constraint
gdp = ccd + ip + ccm2;


// definition of consumption aggregator (pins down ccd)
cc = (omega^(rhoc/(1+rhoc))*ccd^(1/(1+rhoc))+(1-omega)^(rhoc/(1+rhoc))*ccm^(1/(1+rhoc)))^(1+rhoc);


// import demand
ccm = (1-omega)*(pf/pc)^(-(1+rhoc)/rhoc) * cc;

// consumption prices
pc = (omega+(1-omega)*pf^(-1/rhoc))^(-rhoc);

// nfa
pf*nfa/(1+rs2)/exp(-nfa_p/2*(pf*nfa/gdp)) = pf*(nfa(-1)) + ccm2-pf*ccm ;

// nfa to gdp
nfay = pf*nfa/gdp;

// Trade Balance, share of GDP
tby = (ccm2-pf*ccm)/gdp;

// Saving rate
sy = 1-cc/gdp;

// Investment rate
ipy = ip/gdp;

// UIP equation
1/(1+rs)*pf(1)/pf = 1/(1+rs2)/exp(-nfa_p/2*(pf*nfa/gdp)) ;

// This is the home risk-free rate.
1/(1+rs) = beta_p *lambda(1)/lambda;

// Consumption-based real exchange rate
q = pf*pc2/pc;

// Capital
kp = (1-delta_p)*kp(-1) + ip;

// Rental Rate for Labor, FOC with respect to labor
rw = (1-nu_p)*(gdp/(le*exp(n)))*exp(n);

// Rental Rate for Capital
rk = nu_p*(gdp/(kp(-1)*exp(m))) * exp(m);

// Labor-augmenting technology shock
n = rhon_p*n(-1) + nerr;

// Capital Augmenting Technology Shock
m = rhom_p*m(-1) + merr;

///////////////////////////////////////////////////////////////////////////
// Country 2
///////////////////////////////////////////////////////////////////////////

// FOC with respect to consumption
1/cc2 - lambda2*pc2=0;   

// FOC wrt Labor
-chi0_p*(1-le2)^(-chi_p) + lambda2 * rw2 =0;

// Lambda Marginal Utility of consumption
gamma2-lambda2 = 0;

// gamma shadow price of capital
(1-delta_p)*beta_p * gamma2(1) - gamma2 +beta_p *lambda2(1)*rk2(1) = 0;

// Aggregate Output
gdp2 = (kp2(-1)*exp(m2))^(nu_p)* (le2*exp(n2))^(1-nu_p);

// resource constraint
gdp2= ip2 + ccd2 + ccm;

// definition of consumption aggregator (pins down ccd)
cc2 = (omega^(rhoc/(1+rhoc))*ccd2^(1/(1+rhoc))+(1-omega)^(rhoc/(1+rhoc))*ccm2^(1/(1+rhoc)))^(1+rhoc);

//ccd2 = omega*(1/pc2)^(-(1+rhoc)/rhoc) *cc2;

// import demand
ccm2 = (1-omega)*(pf2/pc2)^(-(1+rhoc)/rhoc) * cc2;

pc2 = (omega+(1-omega)*pf2^(-1/rhoc))^(-rhoc);

pf2 = 1/pf;

// Trade Balance (share of GDP)
tby2 = (ccm-pf2*ccm2)/gdp2;

1/(1+rs2) = beta_p *lambda2(1)/lambda2;

// Capital
kp2 = (1-delta_p)*kp2(-1) + ip2;

// Rental Rate for Labor, FOC with respect to labor
rw2 = (1-nu_p)*(gdp2/(le2*exp(n2)))*exp(n2);

// Rental Rate for Capital
rk2 = nu_p*(gdp2/(kp2(-1)*exp(m2))) * exp(m2);

// Consumption-based real exchange rate
q2 = 1/q;

// Labor-augmenting technology shock
n2 = rhon_p*n2(-1) + nerr2;

// Capital Augmenting Technology Shock
m2 = rhom_p*m2(-1) + merr2;

end;


// Steady state values

initval;

///////////////////////////////////////////////////////////////////////////
// Steady state for  country 1
///////////////////////////////////////////////////////////////////////////

// net foreign assets
nfa =0;

// net foreign assets to gdp
nfay = 0;

// consumption based-real exchange rate
q = 1;

// saving rate
sy = s_p;

// investment rate
ipy = s_p;

// short term real rate
rs = 1/beta_p -1;

// Labor
le = le_p;

// Output
gdp = le_p*(s_p/(delta_p))^(nu_p/(1-nu_p));

// Investment
ip = (s_p * gdp);

// Consumption
cc = (gdp - ip);

// domestic part of consumption
ccd = omega*cc;

ccm = (1-omega)*cc;

pf = 1;

pc = 1;

// Capital 
kp = ip/delta_p;

// Rental rate for capital
rk = (delta_p - 1 + 1/beta_p);

// Rental rate for labor
rw = (1-nu_p)*(gdp/le);

// Marginal utility of consumption
lambda = 1/cc;

// GAMMA: Marginal utility of capital
gamma = lambda;

// Labor-augmenting technology
n=0;

// Capital-augmenting technology
m=0;

///////////////////////////////////////////////////////////////////////////
// Steady state for country 2
///////////////////////////////////////////////////////////////////////////
rs2 = 1/beta_p -1;

// nfa2
//nfa2 = 0;

// Consumption-based real exchange rate
q2 = 1;

// Labor
le2 = le_p;

// Output
gdp2 = le_p*(s_p/delta_p)^(nu_p/(1-nu_p));

// Investment
ip2 = (s_p * gdp);

// Consumption
cc2 = (gdp - ip);

// domestic part of consumption
ccd2 = omega*cc2;

ccm2 = (1-omega)*cc2;

pf2 = 1;

pc2 = 1;

// Capital 
kp2 = ip/delta_p;

// Rental rate for capital
rk2 = (delta_p - 1 + 1/beta_p);

// Rental rate for labor
rw2 = (1-nu_p)*(gdp/le);

// Marginal utility of consumption
lambda2 = 1/cc2;

// GAMMA: Marginal utility of capital
gamma2 = lambda2;

// Labor-augmenting technology
n2=0;

// Capital-augmenting technology
m2=0;



end;

shocks;
var nerr; stderr .01;
var merr; stderr .01;
var merr2; stderr .01;
var nerr2; stderr .01;
end;

check;

stoch_simul(order=1,nocorr,nomoments,irf=0);

//stoch_simul(order=1,nocorr,nomoments,noprint,irf=0);
